@@ -36,13 +36,16 @@ function(Data, Prior, Mcmc) {
 #
 # Definitions of functions used within rhierNegbinRw
 #
-
 llnegbin = 
 function(par,X,y, nvar) {
 # Computes the log-likelihood
     beta = par[1:nvar]
-    alpha = exp(par[nvar+1])
-    ll = sum(log(dnbinom(y,size=alpha,mu=exp(X%*%beta))))
+    alpha = exp(par[nvar+1])+1.0e-50
+    mean=exp(X%*%beta)
+    prob=alpha/(alpha+mean)
+    prob=ifelse(prob<1.0e-100,1.0e-100,prob)
+     out=.Internal(dnbinom(y,alpha,prob,TRUE))
+     return(sum(out))
 }
 
 lpostbetai = 
@@ -72,6 +75,7 @@ if(is.null(Data$y)) {pandterm("Requires Data element y")} else {y=Data$y}
 nvar = ncol(X)
 
 if (length(y) != nrow(X)) {pandterm("Mismatch in the number of observations in X and y")}
+nobs=length(y)
 
 #
 # check for prior elements
